/* these get set by the ./configure script eventually */

#undef PREFIX_INSTALL_PATH
#undef HAVE_GGI_MISC_H

